@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,6 +13,6 @@ class StatusbarProgressWidget_Gui : public QWidget
     Q_OBJECT
 public:
     explicit StatusbarProgressWidget_Gui(QWidget *parent = nullptr);
-    ~StatusbarProgressWidget_Gui() = default;
+    ~StatusbarProgressWidget_Gui() override = default;
 };
 
